@@ -25,7 +25,6 @@
 #include <QRandomGenerator>
 
 // KF
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigDialog>
 #include <KLocalizedString>
@@ -35,7 +34,7 @@
 // KDEGames
 #include <KGameClock>
 #include <KScoreDialog>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 
 // LibKMahjongg
 #include <KMahjonggConfigDialog>
@@ -131,17 +130,17 @@ KMahjongg::~KMahjongg()
 
 void KMahjongg::setupKAction()
 {
-    KStandardGameAction::gameNew(this, &KMahjongg::startNewGame, actionCollection());
-    KStandardGameAction::load(this, &KMahjongg::loadGame, actionCollection());
-    KStandardGameAction::save(this, &KMahjongg::saveGame, actionCollection());
-    KStandardGameAction::quit(this, &KMahjongg::close, actionCollection());
-    KStandardGameAction::restart(this, &KMahjongg::restartGame, actionCollection());
+    KGameStandardAction::gameNew(this, &KMahjongg::startNewGame, actionCollection());
+    KGameStandardAction::load(this, &KMahjongg::loadGame, actionCollection());
+    KGameStandardAction::save(this, &KMahjongg::saveGame, actionCollection());
+    KGameStandardAction::quit(this, &KMahjongg::close, actionCollection());
+    KGameStandardAction::restart(this, &KMahjongg::restartGame, actionCollection());
 
     QAction * newNumGame = actionCollection()->addAction(QStringLiteral("game_new_numeric"));
     newNumGame->setText(i18n("New Numbered Game..."));
     connect(newNumGame, &QAction::triggered, this, &KMahjongg::startNewNumeric);
 
-    QAction * action = KStandardGameAction::hint(m_gameView, &GameView::helpMove, this);
+    QAction * action = KGameStandardAction::hint(m_gameView, &GameView::helpMove, this);
     actionCollection()->addAction(action->objectName(), action);
 
     QAction * shuffle = actionCollection()->addAction(QStringLiteral("move_shuffle"));
@@ -152,27 +151,27 @@ void KMahjongg::setupKAction()
     QAction * angleccw = actionCollection()->addAction(QStringLiteral("view_angleccw"));
     angleccw->setText(i18n("Rotate View Counterclockwise"));
     angleccw->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-left")));
-    actionCollection()->setDefaultShortcut(angleccw, Qt::Key_F);
+    KActionCollection::setDefaultShortcut(angleccw, Qt::Key_F);
     connect(angleccw, &QAction::triggered, m_gameView, &GameView::angleSwitchCCW);
 
     QAction * anglecw = actionCollection()->addAction(QStringLiteral("view_anglecw"));
     anglecw->setText(i18n("Rotate View Clockwise"));
     anglecw->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-right")));
-    actionCollection()->setDefaultShortcut(anglecw, Qt::Key_G);
+    KActionCollection::setDefaultShortcut(anglecw, Qt::Key_G);
     connect(anglecw, &QAction::triggered, m_gameView, &GameView::angleSwitchCW);
 
     m_fullscreenAction = KStandardAction::fullScreen(
         this, &KMahjongg::toggleFullscreen, this, actionCollection()
     );
 
-    m_demoAction = KStandardGameAction::demo(this, &KMahjongg::demoMode, actionCollection());
+    m_demoAction = KGameStandardAction::demo(this, &KMahjongg::demoMode, actionCollection());
 
-    KStandardGameAction::highscores(this, &KMahjongg::showHighscores, actionCollection());
-    m_pauseAction = KStandardGameAction::pause(this, &KMahjongg::pause, actionCollection());
+    KGameStandardAction::highscores(this, &KMahjongg::showHighscores, actionCollection());
+    m_pauseAction = KGameStandardAction::pause(this, &KMahjongg::pause, actionCollection());
 
     // move
-    m_undoAction = KStandardGameAction::undo(this, &KMahjongg::undo, actionCollection());
-    m_redoAction = KStandardGameAction::redo(this, &KMahjongg::redo, actionCollection());
+    m_undoAction = KGameStandardAction::undo(this, &KMahjongg::undo, actionCollection());
+    m_redoAction = KGameStandardAction::redo(this, &KMahjongg::redo, actionCollection());
 
     // edit
     QAction * boardEdit = actionCollection()->addAction(QStringLiteral("game_board_editor"));
@@ -379,7 +378,7 @@ void KMahjongg::pause()
 void KMahjongg::showHighscores()
 {
     KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Time, this);
-    const QString layoutName = m_boardLayout->authorProperty(QStringLiteral("Name"));
+    const QString layoutName = m_boardLayout->name();
     ksdialog.setConfigGroup(qMakePair(QByteArray(layoutName.toUtf8()), layoutName));
     ksdialog.exec();
 }
@@ -397,29 +396,17 @@ void KMahjongg::noMovesAvailable()
     m_gameTimer->pause();
     updateState(GameState::Stuck);
 
-    const QIcon newGameIcon = actionCollection()->action(QString::fromLatin1(KStandardGameAction::name(KStandardGameAction::New)))->icon();
-    const QIcon restartIcon = actionCollection()->action(QString::fromLatin1(KStandardGameAction::name(KStandardGameAction::Restart)))->icon();
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const QIcon newGameIcon = actionCollection()->action(KGameStandardAction::name(KGameStandardAction::New))->icon();
+    const QIcon restartIcon = actionCollection()->action(KGameStandardAction::name(KGameStandardAction::Restart))->icon();
     int answer = KMessageBox::questionTwoActionsCancel(
-#else
-    int answer = KMessageBox::questionYesNoCancel(
-#endif
         this,
         i18n("Game Over: You have no moves left."),
         i18n("Game Over"),
         KGuiItem(i18n("New Game"), newGameIcon),
         KGuiItem(i18n("Restart"), restartIcon));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::PrimaryAction) {
-#else
-    if (answer == KMessageBox::Yes) {
-#endif
         startNewGame();
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     } else if (answer == KMessageBox::SecondaryAction) {
-#else
-    } else if (answer == KMessageBox::No) {
-#endif
         restartGame();
     }
 }
@@ -441,9 +428,10 @@ void KMahjongg::startNewGameWithNumber(int item)
     // Use same layout if restarting game or starting a numbered game.
     if (Prefs::randomLayout() && item == -1) {
         QStringList availableLayouts;
-        const QStringList layoutDirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("layouts/"), QStandardPaths::LocateDirectory);
+        const QStringList layoutDirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("layouts"), QStandardPaths::LocateDirectory);
         for (const QString & dir : layoutDirs) {
-            const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+            const QStringList fileNames = QDir(dir).entryList({QStringLiteral("*.desktop")});
+            availableLayouts.reserve(availableLayouts.size() + fileNames.size());
             for (const QString & file : fileNames) {
                 availableLayouts.append(dir + QLatin1Char('/') + file);
             }
@@ -469,7 +457,7 @@ void KMahjongg::startNewGameWithNumber(int item)
 
     if (m_gameView->gameGenerated()) {
         updateState(GameState::Gameplay);
-        setCaption(m_boardLayout->layoutName());
+        setCaption(m_boardLayout->name());
     } else {
         updateState(GameState::Finished);
         m_gameTimer->pause();
@@ -544,7 +532,7 @@ void KMahjongg::gameOver(unsigned short numRemoved, unsigned short cheats)
     //long gameNum = m_pGameView->getGameNumber();
     //theHighScores->checkHighScore(score, elapsed, gameNum, m_pGameView->getBoardName());
     QPointer<KScoreDialog> ksdialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
-    const QString layoutName = m_boardLayout->authorProperty(QStringLiteral("Name"));
+    const QString layoutName = m_boardLayout->name();
     ksdialog->setConfigGroup(qMakePair(QByteArray(layoutName.toUtf8()), layoutName));
     KScoreDialog::FieldInfo scoreInfo;
     scoreInfo[KScoreDialog::Score].setNum(score);
@@ -750,27 +738,15 @@ void KMahjongg::saveGame()
 
 bool KMahjongg::askSaveGame(const QString &dontAskAgainName)
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const KMessageBox::ButtonCode ret = KMessageBox::questionTwoActionsCancel(this,
-#else
-    const KMessageBox::ButtonCode ret = KMessageBox::questionYesNoCancel(this, 
-#endif
             i18n("Do you want to save your game?"), i18n("Save game?"), KStandardGuiItem::save(), 
             KStandardGuiItem::dontSave(), KStandardGuiItem::cancel(), dontAskAgainName);
 
     switch (ret) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::PrimaryAction:
-#else
-    case KMessageBox::ButtonCode::Yes:
-#endif
         saveGame();
         break;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::SecondaryAction:
-#else
-    case KMessageBox::ButtonCode::No:
-#endif
         break;
     case KMessageBox::ButtonCode::Cancel:
         return false;
